@@ -181,6 +181,12 @@ goa_provider_dialog_dispose (GObject *object)
 {
   GoaProviderDialog *self = GOA_PROVIDER_DIALOG (object);
 
+  if (self->task_cancellable != NULL && self->task_cancellable_id != 0)
+    {
+      g_cancellable_disconnect (self->task_cancellable, self->task_cancellable_id);
+      self->task_cancellable_id = 0;
+    }
+
   g_cancellable_cancel (self->cancellable);
 
   G_OBJECT_CLASS (goa_provider_dialog_parent_class)->dispose (object);
@@ -738,15 +744,22 @@ goa_provider_dialog_push_account (GoaProviderDialog *self,
     gtk_box_append (GTK_BOX (box), content);
 
   /* Remove */
-  action_button = gtk_button_new_with_mnemonic (_("_Remove…"));
-  gtk_widget_set_halign (action_button, GTK_ALIGN_CENTER);
-  gtk_widget_add_css_class (action_button, "pill");
-  gtk_box_append (GTK_BOX (box), action_button);
+  group = gtk_list_box_new ();
+  gtk_widget_add_css_class (group, "boxed-list");
+  gtk_box_append (GTK_BOX (box), group);
+
+  action_button = g_object_new (ADW_TYPE_BUTTON_ROW,
+                                "activatable",   TRUE,
+                                "selectable",    FALSE,
+                                "title",         _("_Remove…"),
+                                "use-underline", TRUE,
+                                NULL);
+  gtk_list_box_append (GTK_LIST_BOX (group), action_button);
 
   g_object_set_data (G_OBJECT (page), "goa-dialog-banner", banner);
 
   g_signal_connect_object (action_button,
-                           "clicked",
+                           "activated",
                            G_CALLBACK (on_remove_activated),
                            self,
                            G_CONNECT_SWAPPED);
@@ -1156,7 +1169,10 @@ goa_provider_task_run_in_dialog_cb (GoaProviderDialog *self,
 
   g_signal_handlers_disconnect_by_func (self, goa_provider_task_run_in_dialog_cb, task);
 
-  if (self->task_cancellable != NULL && self->task_cancellable_id != 0)
+  /* If the cancellable was triggered we would deadlock disconnecting here,
+   * so we'll do it later in dispose().
+   */
+  if (!g_cancellable_is_cancelled (self->task_cancellable) && self->task_cancellable_id != 0)
     {
       g_cancellable_disconnect (self->task_cancellable, self->task_cancellable_id);
       self->task_cancellable_id = 0;
